# Copyright 2018 The Rekcurd Authors.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from rekcurd import _project
from rekcurd import _version

__project__ = _project.__project__
__version__ = _version.__version__

from rekcurd.core import (
    Rekcurd, RekcurdPack, RekcurdInput, RekcurdOutput,
    RekcurdWorkerServicer, RekcurdDashboardServicer
)
